from flask import Flask

from portal import db


class FlaskConfigEntry(db.Model):
    """
    A configuration entry for Flask (a key-value pair) as persisted in a database
    """

    __tablename__ = "flask_config"

    key = db.Column(db.String(256), primary_key=True)
    value = db.Column(db.String(4096))

    def apply(self, app: Flask) -> None:
        """
        Apply the config to the given application (i.e. set app.config[self.key] to self.value)
        """
        app.config[self.key] = self.value
